##  Fact Sheet Update Details
Equivalent to the Email channel you will be able to opt-in for showing details in Fact Sheet update notifications on Microsoft Teams. Once this is enabled, the users of your workspace that have subscribed to Fact Sheet updated notifications on Microsoft Teams will see which field has changed on the Fact Sheet, as well as the content of what has changed.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d34c07a441014b6f491a53c01b178_LowRes.png)
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
